@@ -60,8 +60,12 @@ typedef int ssize_t;
 #define PATH_MAILLOG	"/var/log/mail"
 #endif
 
-#ifdef HPUX10
+#if defined(HPUX10) || defined(HPUX11)
 #define HAVE_GETRUSAGE
+#ifdef HPUX11
+#define HAVE_SNPRINTF
+#define HAVE_VSNPRINTF
+#endif
 #define SOCKLEN_T	int
 #define PATH_TMP	"/tmp"
 #define PATH_VAR_TMP	"/var/tmp"
@@ -128,6 +132,23 @@ typedef int ssize_t;
 #define PATH_SYSLOG     "/var/adm/messages"
 #endif
 
+#ifdef SOLARIS_251
+#define HAVE_GETRUSAGE
+#define PID_T_IS_LONG_INT
+#define SOCKLEN_T       int
+#define PATH_TMP        "/tmp"
+#define PATH_VAR_TMP    "/var/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/var/adm/wtmp"
+#define PATH_UTMP       "/var/adm/utmp"
+#define PATH_SYSLOG     "/var/adm/messages"
+#ifdef S_ISSOCK
+#undef S_ISSOCK
+#define       S_ISSOCK        S_ISFIFO
+#endif
+int getrusage(int who, struct rusage *rusage);
+#endif
+
 #ifdef SOLARIS_OLD
 #define HAVE_GETRUSAGE
 #define PID_T_IS_LONG_INT
